@@ -1,24 +1,7 @@
-#################################################################################
-##
-##   R package Rsolnp by Alexios Ghalanos and Stefan Theussl Copyright (C) 2009
-##   This file is part of the R package Rsolnp.
-##
-##   The R package Rsolnp is free software: you can redistribute it and/or modify
-##   it under the terms of the GNU General Public License as published by
-##   the Free Software Foundation, either version 3 of the License, or
-##   (at your option) any later version.
-##
-##   The R package Rsolnp is distributed in the hope that it will be useful,
-##   but WITHOUT ANY WARRANTY; without even the implied warranty of
-##   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-##   GNU General Public License for more details.
-##
-#################################################################################
-
 benchmarkids <- function()
 {
 return(c("Powell", "Wright4", "Wright9", "Alkylation", "Entropy", "Box", "RosenSuzuki",
-				"RachevRatio", "KappaRatio", "Electron", "Permutation"))
+				"Electron", "Permutation"))
 }
 
 
@@ -34,8 +17,6 @@ benchmark <- function( id = "Powell")
 			Entropy = .entropy(),
 			Box = .box(),
 			RosenSuzuki = .rosensuzuki(),
-			RachevRatio = .rachevratio(),
-			KappaRatio = .kapparatio(),
 			Electron = .electron(),
 			Permutation = .permutation())
 	return(ans)
@@ -370,142 +351,7 @@ from Problem 43 of Hock and Schittkowski (1981).")
 	return(bt)
 }
 
-#---------------------------------------------------------------------------------
-# portfolio optimization problems / benchmarked against SNOPT (SOL) - with tomlab
-# interface for matlab
-.rachevratio = function()
-{
-	dj30 = as.matrix(get(data(dji30ret)))
 
-	.VaR = function(x, alpha = 0.05)
-	{
-		x = as.matrix(x)
-		VaR = quantile(x, probs = alpha, type = 1)
-		VaR
-	}
-
-	.CVaR = function(x, alpha = 0.05)
-	{
-		x = as.matrix(x)
-		VaR = .VaR(x, alpha)
-		X = as.vector(x[, 1])
-		CVaR = VaR - 0.5 * mean(((VaR-X) + abs(VaR-X))) / alpha
-		CVaR
-	}
-	.fn1 = function(x,ret)
-	{
-		port=ret%*%x
-		obj=-.CVaR(-port)/.CVaR(port)
-		return(obj)
-	}
-
-	# abs(sum) of weights ==1
-	.eqn1  = function(x,ret)
-	{
-		sum(abs(x))
-	}
-	LB=rep(0,30)
-	UB=rep(0.1,30)
-	pars=rep(1/30,30)
-
-	.x0 = rep(1/30,30)
-	ctrl = list(delta = 1e-10, tol = 1e-8, trace = 0)
-	ans = solnp(.x0, fun = .fn1, eqfun = .eqn1, eqB = 1, LB = LB, UB = UB, control = ctrl, ret = dj30)
-	snopt = list()
-	snopt$fn = -1.002162
-	snopt$pars = c(0, 0.08128943, 0, 0, 0, 0.01997529, 0, 0, 0.04208868, 0, 0, 0.1, 0.04206685,
-	0, 0.1, 0.1, 0.1, 0, 0.1, 0, 0, 0, 0.09698527, 0, 0, 0.1, 0, 0.01759449, 0.1, 0)
-	snopt$nfun = 3867
-	snopt$iter = 8
-	snopt$elapsed = 7.534
-
-	bt = data.frame( solnp = rbind(round(ans$values[length(ans$values)], 5L),
-					round(ans$outer.iter, 0L),
-					round(ans$convergence, 0L),
-					round(ans$nfuneval, 0L),
-					round(ans$elapsed, 3L),
-					matrix(round(ans$pars, 5L), ncol = 1L)),
-			snopt =  rbind(round(snopt$fn, 5L),
-					round(snopt$iter, 0L),
-					round(0, 0L),
-					round(snopt$nfun, 0L),
-					round(snopt$elapsed, 3L),
-					matrix(round(snopt$pars, 5L), ncol = 1L)) )
-	rownames(bt) = c("funcValue", "majorIter", "exitFlag", "nfunEval", "time(sec)",
-			paste("par.", 1L:length(ans$pars), sep = "") )
-	colnames(bt) = c("solnp", "snopt")
-	attr(bt, "description") = paste("The Rachev Ratio problem minimizes a portfolio's Rachev ratio.
-It has one linear equality constraint and variable bounds. See Rachev (2000) for details.")
-	return(bt)
-}
-
-# Kappa Optimization (Kaplan and Knowles...subsumes omega and sortino measures among others)
-# It is in fact the excess to benchmark return divided by the standardized Lower Partial Moment
-# measure and as such Kaplan and Knowles are not entirely entitled to claim a special measure
-# for this as it was described among others by Fishburn in the 70's.
-#----------------------------------------------------------------------------------
-# setup the required sample functions:
-# r is the threshold, n is the power (n=1 + 1 is the omega measure of Shadwick and Keating,
-# while n=2 is the sortino measure.)
-
-.kapparatio = function()
-{
-
-	dj30 = as.matrix(get(data(dji30ret)))
-
-	.kappa = function(port, r, n)
-	{
-		z = mean((port< r) * (r-port)^n)
-		sg = sign(z)
-		(mean(port) - r) / (sg*abs(z)^(1/n))
-	}
-
-
-	.fn1 = function(x, ret, r, n)
-	{
-		port = ret%*%x
-		obj = -.kappa(port,r,n)
-		return(obj)
-	}
-
-	# abs(sum) of weights ==1
-	.eqn1  = function(x, ret, r, n)
-	{
-		sum(abs(x))
-	}
-
-	LB = rep(0,30)
-	UB = rep(0.1,30)
-	.x0 = rep(1/30,30)
-	ctrl = list(delta = 1e-10, tol = 1e-8, trace = 0)
-	ans = solnp(.x0, fun = .fn1, eqfun = .eqn1, eqB = 1, LB = LB, UB = UB, control=ctrl, ret=dj30, r = 0, n = 2)
-	snopt = list()
-	snopt$fn = -0.06160942
-	snopt$pars = c(0, 0, 0, 0, 0, 0, 0.1, 0, 0, 0, 0, 0.1, 0, 0, 0, 0.1, 0, 0,
-			0.08561978, 0.1, 0, 0, 0.1, 0, 0.1, 0.01628157, 0.09809865, 0, 0.1, 0.1)
-	snopt$nfun = 1234
-	snopt$iter = 3
-	snopt$elapsed = 0.983
-
-	bt = data.frame( solnp = rbind(round(ans$values[length(ans$values)], 5L),
-					round(ans$outer.iter, 0L),
-					round(ans$convergence, 0L),
-					round(ans$nfuneval, 0L),
-					round(ans$elapsed, 3L),
-					matrix(round(ans$pars, 5L), ncol = 1L)),
-			snopt =  rbind(round(snopt$fn, 5L),
-					round(snopt$iter, 0L),
-					round(0, 0L),
-					round(snopt$nfun, 0L),
-					round(snopt$elapsed, 3L),
-					matrix(round(snopt$pars, 5L), ncol = 1L)) )
-	rownames(bt) <- c("funcValue", "majorIter", "exitFlag", "nfunEval", "time(sec)",
-			paste("par.", 1L:length(ans$pars), sep = "") )
-	colnames(bt) = c("solnp", "snopt")
-	attr(bt, "description") = paste("The PortKappa problem minimizes a portfolio's Kappa ratio.
-It has one linear equality constraint and variable bounds. See Kaplan and Knowles (2004) for details.")
-	return(bt)
-}
 
 #----------------------------------------------------------------------------------
 # Some Problems in Global Optimization
@@ -626,4 +472,4 @@ It has one linear equality constraint and variable bounds. See Kaplan and Knowle
 	colnames(bt) = c("solnp", "expected")
 	attr(bt, "description") = paste("Permutation Problem PERM(4,0.5).")
 
-}
\ No newline at end of file
+}
